@@ -362,15 +362,6 @@ void linphone_call_redirected(LinphoneCore *lc, int cid,int code, const char *co
 	}
 }
 
-static int get_audio_max_bw(const LinphoneCore *lc){
-	int dbw=linphone_core_get_download_bandwidth(lc);
-	int ubw=linphone_core_get_upload_bandwidth(lc);
-	if (dbw==0)
-		dbw=1<<30;
-	if (ubw==0)
-		ubw=1<<30;
-	return MIN(MIN(dbw,ubw),64);
-}
 
 /* these are the SdpHandler callbacks: we are called in to be aware of the content
 of the SDP messages exchanged */
@@ -406,7 +397,7 @@ int linphone_set_audio_offer(sdp_context_t *ctx)
 	payload.pt=rtp_profile_get_payload_number_from_mime(lc->local_profile,"telephone-event");
 	payload.a_rtpmap="telephone-event/8000";
 	payload.a_fmtp="0-11";
-	payload.b_as_bandwidth=get_audio_max_bw(lc);
+	if (lc->dw_audio_bw>0) payload.b_as_bandwidth=lc->dw_audio_bw;
 	sdp_context_add_audio_payload(ctx,&payload);
 	return 0;
 }
@@ -434,7 +425,8 @@ int linphone_set_video_offer(sdp_context_t *ctx)
 			payload.a_fmtp=codec->recv_fmtp;
 			if(firsttime){
 				firsttime=FALSE;
-				payload.b_as_bandwidth=codec->normal_bitrate/1000;
+				if (lc->dw_video_bw>0)
+					payload.b_as_bandwidth=lc->dw_video_bw;
 			}
 			sdp_context_add_video_payload(ctx,&payload);
 			ms_free(payload.a_rtpmap);
@@ -449,7 +441,7 @@ typedef enum {
 	SupportedAndValid  /* valid= the presence of this codec is enough to make a call */
 }SupportLevel;
 
-SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payload,RtpProfile *local_profile,RtpProfile *dialog_profile)
+SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payload,RtpProfile *local_profile,RtpProfile *dialog_profile, bool_t answering)
 {
 	int localpt;
 	SupportLevel ret;
@@ -469,7 +461,7 @@ SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payl
 			return Unsupported;
 		}
 		if (strcmp(rtppayload->mime_type,"telephone-event")!=0){
-			if (!linphone_core_check_payload_type_usability(lc,rtppayload) ){
+			if (answering && !linphone_core_check_payload_type_usability(lc,rtppayload) ){
 				ms_warning("payload %s is not usable",rtppayload->mime_type);
 				return Unsupported;
 			}
@@ -480,20 +472,27 @@ SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payl
 			ret=SupportedAndValid;
 		}else ret=Supported;
 		if (dialog_profile!=NULL){
-			int bw;
+			int dbw,ubw;
 			/* this payload is supported in our local rtp profile, so add it to the dialog rtp
 			profile */
 			rtppayload=payload_type_clone(rtppayload);
 			rtp_profile_set_payload(dialog_profile,payload->pt,rtppayload);
 			/* add to the rtp payload type some other parameters (bandwidth) */
-			if (rtppayload->type==PAYLOAD_VIDEO)
-				bw=rtppayload->normal_bitrate/1000;
-			else 
-				bw=get_audio_max_bw(lc);
-			if (payload->b_as_bandwidth!=0){
-				rtppayload->normal_bitrate=MIN(payload->b_as_bandwidth*1000,rtppayload->normal_bitrate);
+			if (rtppayload->type==PAYLOAD_VIDEO){
+				dbw=lc->dw_video_bw;
+				ubw=lc->up_video_bw;
+			}else{ 
+				dbw=lc->dw_audio_bw;
+				ubw=lc->up_audio_bw;
 			}
-			payload->b_as_bandwidth=bw;
+			if (payload->b_as_bandwidth!=0){
+				/*obey to remote bandwidth constraint AND our own upbandwidth constraint*/
+				rtppayload->normal_bitrate=1000*get_min_bandwidth(
+					payload->b_as_bandwidth,
+					ubw);
+			}
+			/* but anyway give our download bandwidth constraint*/
+			payload->b_as_bandwidth=dbw;
 			if (payload->a_fmtp!=NULL){
 				payload_type_set_send_fmtp(rtppayload,payload->a_fmtp);
 			}
@@ -518,7 +517,7 @@ int linphone_accept_audio_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	}
 	remote_profile=call->profile;
 	/* see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile);
+	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile,TRUE);
 	if (supported==Unsupported) {
 		ms_message("Refusing audio codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
@@ -557,7 +556,7 @@ int linphone_accept_video_offer(sdp_context_t *ctx,sdp_payload_t *payload)
 	}
 	remote_profile=call->profile;
 	/* see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile);
+	supported=linphone_payload_is_supported(lc,payload,lc->local_profile,remote_profile,TRUE);
 	if (supported==Unsupported) {
 		ms_message("Refusing video codec %i (%s)",payload->pt,payload->a_rtpmap);
 		return -1;
@@ -588,7 +587,7 @@ int linphone_read_audio_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 	SupportLevel supported;
 	
 	/* paranoid check: see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile);
+	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile,FALSE);
 	if (supported==Unsupported) {
 		ms_warning("This remote sip phone did not answer properly to my sdp offer!");
 		return 0;
@@ -616,7 +615,7 @@ int linphone_read_video_answer(sdp_context_t *ctx,sdp_payload_t *payload)
 	SupportLevel supported;
 	
 	/* paranoid check: see if this codec is supported in our local rtp profile*/
-	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile);
+	supported=linphone_payload_is_supported(lc, payload,lc->local_profile,call->profile,FALSE);
 	if (supported==Unsupported) {
 		ms_warning("This remote sip phone did not answer properly to my sdp offer!");
 		return 0;
