@@ -40,16 +40,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 void linphone_core_enable_video_preview(LinphoneCore *lc, bool_t val);
 bool_t linphone_core_video_preview_enabled(const LinphoneCore *lc);
 void linphone_core_get_local_ip(LinphoneCore *lc, const char *dest, char *result);
-
-
-const double bandwidths[5]=
-{
-	28800.0,	/*28k modem*/
-	28800.0, /*56k modem*/
-	64000.0, /*64k modem (numeris)*/
-	128000.0,	/*adsl or cable*/
-	10e6, /* ethernet */
-};/* carefull: these are the upstream bandwidth !!!*/
+static void apply_nat_settings(LinphoneCore *lc);
 
 /* relative path where is stored local ring*/
 #define LOCAL_RING "rings/oldphone.wav"
@@ -229,14 +220,13 @@ net_config_read (LinphoneCore *lc)
 	linphone_core_set_download_bandwidth(lc,tmp);
 	tmp=lp_config_get_int(config,"net","upload_bw",0);
 	linphone_core_set_upload_bandwidth(lc,tmp);
-	tmp=lp_config_get_int(config,"net","use_stun",0);
-	linphone_core_enable_stun(lc,tmp);
 	linphone_core_set_stun_server(lc,lp_config_get_string(config,"net","stun_server",NULL));
 	tmpstr=lp_config_get_string(lc->config,"net","nat_address",NULL);
 	if (tmpstr!=NULL && (strlen(tmpstr)<1)) tmpstr=NULL;
-	tmp=lp_config_get_int(lc->config,"net","use_nat",0);
 	linphone_core_set_nat_address(lc,tmpstr);
-	linphone_core_use_nat_address(lc,tmp);		
+	tmp=lp_config_get_int(lc->config,"net","firewall_policy",0);
+	linphone_core_set_firewall_policy(lc,tmp);
+	tmp=lp_config_get_int(lc->config,"net","nat_sdp_only",0);
 }
 
 
@@ -474,10 +464,40 @@ void autoreplier_config_init(LinphoneCore *lc)
 
 void linphone_core_set_download_bandwidth(LinphoneCore *lc, int bw){
 	lc->net_conf.download_bw=bw;
+	if (bw==0){ /*infinite*/
+		lc->dw_audio_bw=-1;
+		lc->dw_video_bw=-1;
+		return;
+	}else if (bw>=512){
+		lc->dw_audio_bw=80;
+	}else if (bw>=128){
+		if (linphone_core_video_enabled(lc))
+			lc->dw_audio_bw=40;
+		else
+			lc->dw_audio_bw=bw;
+	}else{
+		lc->dw_audio_bw=bw;
+	}
+	lc->dw_video_bw=bw-lc->dw_audio_bw;
 }
 
 void linphone_core_set_upload_bandwidth(LinphoneCore *lc, int bw){
 	lc->net_conf.upload_bw=bw;
+	if (bw==0){ /*infinite*/
+		lc->up_audio_bw=-1;
+		lc->up_video_bw=-1;
+		return;
+	}else if (bw>=512){
+		lc->up_audio_bw=80;
+	}else if (bw>=128){
+		if (linphone_core_video_enabled(lc))
+			lc->up_audio_bw=40;
+		else 
+			lc->up_audio_bw=bw;
+	}else{
+		lc->up_audio_bw=bw;
+	}
+	lc->up_video_bw=bw-lc->up_audio_bw;
 }
 
 int linphone_core_get_download_bandwidth(const LinphoneCore *lc){
@@ -488,16 +508,6 @@ int linphone_core_get_upload_bandwidth(const LinphoneCore *lc){
 	return lc->net_conf.upload_bw;
 }
 
-static PayloadType experimental_theora={
-	.type=PAYLOAD_VIDEO,
-	.clock_rate=90000,
-	.bits_per_sample=0,
-	.zero_pattern=NULL,
-	.pattern_length=0,
-	.normal_bitrate=256000,
-	.mime_type="x-theora"
-};
-
 void
 linphone_core_init (LinphoneCore * lc, const LinphoneCoreVTable *vtable, const char *config_path, void * userdata)
 {
@@ -509,10 +519,9 @@ linphone_core_init (LinphoneCore * lc, const LinphoneCoreVTable *vtable, const c
 	rtp_profile_set_payload(&av_profile,116,&payload_type_truespeech);
 	rtp_profile_set_payload(&av_profile,101,&payload_type_telephone_event);
 	
-	/*rtp_profile_set_payload(&av_profile,97,&payload_type_theora);*/
-	rtp_profile_set_payload(&av_profile,96,&experimental_theora);
+	rtp_profile_set_payload(&av_profile,97,&payload_type_theora);
 	rtp_profile_set_payload(&av_profile,98,&payload_type_h263_1998);
-	/*rtp_profile_set_payload(&av_profile,99,&payload_type_mp4v);*/
+	rtp_profile_set_payload(&av_profile,99,&payload_type_mp4v);
 
 	ms_init();
 	
@@ -554,12 +563,12 @@ LinphoneCore *linphone_core_new(const LinphoneCoreVTable *vtable,
 	return core;
 }
 
-const MSList *linphone_core_get_audio_codecs(LinphoneCore *lc)
+const MSList *linphone_core_get_audio_codecs(const LinphoneCore *lc)
 {
 	return lc->codecs_conf.audio_codecs;
 }
 
-const MSList *linphone_core_get_video_codecs(LinphoneCore *lc)
+const MSList *linphone_core_get_video_codecs(const LinphoneCore *lc)
 {
 	return lc->codecs_conf.video_codecs;
 }
@@ -606,20 +615,23 @@ static bool_t stun_get_localip(LinphoneCore *lc, char *result){
 
 /*result must be an array of chars at least LINPHONE_IPADDR_SIZE */
 void linphone_core_get_local_ip(LinphoneCore *lc, const char *dest, char *result){
-	const char *loc_addr;
 	char *tmp=NULL;
-	loc_addr=linphone_core_get_nat_address_if_used(lc);
-	if (loc_addr!=NULL){
-		strncpy(result,loc_addr,LINPHONE_IPADDR_SIZE);
+	if (lc->apply_nat_settings){
+		apply_nat_settings(lc);
+		lc->apply_nat_settings=false;
+	}
+	if (linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_NAT_ADDRESS){
+		strncpy(result,linphone_core_get_nat_address(lc),LINPHONE_IPADDR_SIZE);
 		return;
 	}
-	if (linphone_core_stun_enabled(lc)) {
+	if (linphone_core_get_firewall_policy(lc)==LINPHONE_POLICY_USE_STUN) {
 		if (lc->sip_conf.ipv6_enabled){
 			ms_warning("stun support is not implemented for ipv6");
 		}else{
 			ms_message("doing stun lookup for local address...");
 			if (stun_get_localip(lc,result)){
-				eXosip_set_firewallip(result);
+				if (!lc->net_conf.nat_sdp_only)
+					eXosip_set_firewallip(result);
 				return;
 			}
 			ms_warning("stun lookup failed, falling back to a local interface...");
@@ -723,22 +735,17 @@ MSList * linphone_core_get_friend_list(LinphoneCore *lc)
 	return lc->friends;
 }
 
-int linphone_core_get_connection_type(LinphoneCore *lc)
-{
-	return lc->net_conf.con_type;
-}
-
 int linphone_core_get_audio_jittcomp(LinphoneCore *lc)
 {
 	return lc->rtp_conf.audio_jitt_comp;
 }
 
-int linphone_core_get_audio_port(LinphoneCore *lc)
+int linphone_core_get_audio_port(const LinphoneCore *lc)
 {
 	return lc->rtp_conf.audio_rtp_port;
 }
 
-int linphone_core_get_video_port(LinphoneCore *lc){
+int linphone_core_get_video_port(const LinphoneCore *lc){
 	return lc->rtp_conf.video_rtp_port;
 }
 
@@ -810,6 +817,14 @@ void linphone_core_enable_ipv6(LinphoneCore *lc, bool_t val){
 	}
 }
 
+static void display_bandwidth(RtpSession *as, RtpSession *vs){
+	ms_message("bandwidth usage: audio=[d=%.1f,u=%.1f] video=[d=%.1f,u=%.1f] kbit/sec",
+	(as!=NULL) ? (rtp_session_compute_recv_bandwidth(as)*1e-3) : 0,
+	(as!=NULL) ? (rtp_session_compute_send_bandwidth(as)*1e-3) : 0,
+	(vs!=NULL) ? (rtp_session_compute_recv_bandwidth(vs)*1e-3) : 0,
+	(vs!=NULL) ? (rtp_session_compute_send_bandwidth(vs)*1e-3) : 0);
+}
+
 void linphone_core_iterate(LinphoneCore *lc)
 {
 	eXosip_event_t *ev;
@@ -835,12 +850,25 @@ void linphone_core_iterate(LinphoneCore *lc)
 	}
 	if (lc->call!=NULL){
 		LinphoneCall *call=lc->call;
+		int elapsed;
+		time_t curtime=time(NULL);
 		if (call->dir==LinphoneCallIncoming && call->state==LCStateRinging){
-			int elapsed=time(NULL)-call->start_time;
+			elapsed=curtime-call->start_time;
 			ms_message("incoming call ringing for %i seconds",elapsed);
 			if (elapsed>lc->sip_conf.inc_timeout){
 				linphone_core_terminate_call(lc,NULL);
 			}
+		}else if (call->state==LCStateAVRunning){
+			elapsed=curtime-lc->prevtime;
+			if (elapsed>=1){
+				RtpSession *as=NULL,*vs=NULL;
+				lc->prevtime=curtime;
+				if (lc->audiostream!=NULL)
+					as=lc->audiostream->session;
+				if (lc->videostream!=NULL)
+					vs=lc->videostream->session;
+				display_bandwidth(as,vs);
+			}
 		}
 	}
 
@@ -1266,7 +1294,7 @@ int linphone_core_terminate_call(LinphoneCore *lc, const char *url)
 int linphone_core_send_publish(LinphoneCore *lc,
 			       LinphoneOnlineStatus presence_mode)
 {
-	MSList *elem;
+	const MSList *elem;
 	for (elem=linphone_core_get_proxy_config_list(lc);elem!=NULL;elem=ms_list_next(elem)){
 		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*)elem->data;
 		if (cfg->publish) linphone_proxy_config_send_publish(cfg,presence_mode);
@@ -1493,20 +1521,13 @@ void linphone_core_set_stun_server(LinphoneCore *lc, const char *server){
 	if (server)
 		lc->net_conf.stun_server=ms_strdup(server);
 	else lc->net_conf.stun_server=NULL;
+	lc->apply_nat_settings=TRUE;
 }
 
 const char * linphone_core_get_stun_server(const LinphoneCore *lc){
 	return lc->net_conf.stun_server;
 }
 
-void linphone_core_enable_stun(LinphoneCore *lc, bool_t val){
-	lc->net_conf.stun_enabled=val;
-}
-
-bool_t linphone_core_stun_enabled(const LinphoneCore *lc){
-	return lc->net_conf.stun_enabled;
-}
-
 static void apply_nat_settings(LinphoneCore *lc){
 	char *wmsg;
 	char *tmp=NULL;
@@ -1514,7 +1535,7 @@ static void apply_nat_settings(LinphoneCore *lc){
 	struct addrinfo hints,*res;
 	const char *addr=lc->net_conf.nat_address;
 	
-	if (lc->net_conf.use_nat && addr!=NULL && strlen(addr)>0){
+	if (lc->net_conf.firewall_policy==LINPHONE_POLICY_USE_NAT_ADDRESS && addr!=NULL && strlen(addr)>0){
 		/*check the ip address given */
 		memset(&hints,0,sizeof(struct addrinfo));
 		if (lc->sip_conf.ipv6_enabled)
@@ -1529,6 +1550,7 @@ static void apply_nat_settings(LinphoneCore *lc){
 			ms_warning(wmsg); // what is this for ?
 			lc->vtable.display_warning(lc, wmsg);
 			ms_free(wmsg);
+			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_NO_FIREWALL);
 			return;
 		}
 		/*now get it as an numeric ip address */
@@ -1542,14 +1564,16 @@ static void apply_nat_settings(LinphoneCore *lc){
 			ms_free(wmsg);
 			ms_free(tmp);
 			freeaddrinfo(res);
+			linphone_core_set_firewall_policy(lc,LINPHONE_POLICY_NO_FIREWALL);
 			return;
 		}
 		freeaddrinfo(res);
 	}
 
-	if (lc->net_conf.use_nat ){
+	if (lc->net_conf.firewall_policy==LINPHONE_POLICY_USE_NAT_ADDRESS){
 		if (tmp!=NULL){
-			eXosip_set_firewallip(tmp);
+			if (!lc->net_conf.nat_sdp_only)
+				eXosip_set_firewallip(tmp);
 			ms_free(tmp);
 		}
 		else 
@@ -1560,14 +1584,6 @@ static void apply_nat_settings(LinphoneCore *lc){
 	}
 }
 
-void linphone_core_use_nat_address(LinphoneCore *lc, bool_t val){
-	lc->net_conf.use_nat=val;
-	apply_nat_settings(lc);
-}
-
-bool_t linphone_core_nat_address_used(const LinphoneCore *lc){
-	return lc->net_conf.use_nat;
-}
 
 void linphone_core_set_nat_address(LinphoneCore *lc, const char *addr)
 {
@@ -1576,17 +1592,21 @@ void linphone_core_set_nat_address(LinphoneCore *lc, const char *addr)
 	}
 	if (addr!=NULL) lc->net_conf.nat_address=ms_strdup(addr);
 	else lc->net_conf.nat_address=NULL;
-	apply_nat_settings(lc);
+	lc->apply_nat_settings=TRUE;
 }
 
-const char *linphone_core_get_nat_address(LinphoneCore *lc)
+const char *linphone_core_get_nat_address(const LinphoneCore *lc)
 {
 	return lc->net_conf.nat_address;
 }
 
-const char *linphone_core_get_nat_address_if_used(LinphoneCore *lc){
-	if (lc->net_conf.use_nat && lc->net_conf.nat_address!=NULL && strlen(lc->net_conf.nat_address)>0) return lc->net_conf.nat_address;
-	else return NULL;		
+void linphone_core_set_firewall_policy(LinphoneCore *lc, LinphoneFirewallPolicy pol){
+	lc->net_conf.firewall_policy=pol;
+	lc->apply_nat_settings=TRUE;
+}
+
+LinphoneFirewallPolicy linphone_core_get_firewall_policy(const LinphoneCore *lc){
+	return lc->net_conf.firewall_policy;
 }
 
 MSList * linphone_core_get_call_logs(LinphoneCore *lc){
@@ -1619,6 +1639,11 @@ void linphone_core_enable_video(LinphoneCore *lc, bool_t val){
 #endif
 	lc->video_conf.enabled=val;
 	linphone_core_enable_video_preview(lc,val);
+	/* need to re-apply network bandwidth settings*/
+	linphone_core_set_download_bandwidth(lc,
+		linphone_core_get_download_bandwidth(lc));
+	linphone_core_set_upload_bandwidth(lc,
+		linphone_core_get_upload_bandwidth(lc));
 }
 
 bool_t linphone_core_video_enabled(LinphoneCore *lc){
@@ -1679,14 +1704,11 @@ void net_config_uninit(LinphoneCore *lc)
 	lp_config_set_int(lc->config,"net","download_bw",config->download_bw);
 	lp_config_set_int(lc->config,"net","upload_bw",config->upload_bw);
 	
-	lp_config_set_int(lc->config,"net","use_stun",config->stun_enabled);
 	if (config->stun_server!=NULL)
 		lp_config_set_string(lc->config,"net","stun_server",config->stun_server);
-
-	lp_config_set_int(lc->config,"net","use_nat",config->use_nat);
 	if (config->nat_address!=NULL)
 		lp_config_set_string(lc->config,"net","nat_address",config->nat_address);
-	
+	lp_config_set_int(lc->config,"net","firewall_policy",config->firewall_policy);
 }
 
 
