@@ -73,9 +73,8 @@ typedef struct net_config
 	char *stun_server;
 	int download_bw;
 	int upload_bw;
-	int con_type;			/* type of connection 28k 56k 128k adsl ...*/
-	bool_t use_nat;
-	bool_t stun_enabled;
+	int firewall_policy;
+	bool_t nat_sdp_only;
 }net_config_t;
 
 
@@ -358,6 +357,12 @@ typedef enum _LinphoneOnlineStatus{
 	LINPHONE_STATUS_END
 }LinphoneOnlineStatus;
 
+typedef enum _LinphoneFirewallPolicy{
+	LINPHONE_POLICY_NO_FIREWALL,
+	LINPHONE_POLICY_USE_NAT_ADDRESS,
+	LINPHONE_POLICY_USE_STUN
+} LinphoneFirewallPolicy;
+
 typedef struct _LinphoneCore
 {
 	LinphoneCoreVTable vtable;
@@ -395,7 +400,13 @@ typedef struct _LinphoneCore
 	ms_mutex_t lock;
 	char *play_file;
 	char *rec_file;
+	time_t prevtime;
+	int dw_audio_bw;
+	int up_audio_bw;
+	int dw_video_bw;
+	int up_video_bw;
 	bool_t use_files;
+	bool_t apply_nat_settings;
 #ifdef VINCENT_MAURY_RSVP
 	/* QoS parameters*/
 	int rsvp_enable;
@@ -459,11 +470,11 @@ int linphone_core_change_qos(LinphoneCore *lc, int answer); /* answer = 1 for ye
 #endif
 
 /* returns a MSList of PayloadType */
-const MSList *linphone_core_get_audio_codecs(LinphoneCore *lc);
+const MSList *linphone_core_get_audio_codecs(const LinphoneCore *lc);
 
 int linphone_core_set_audio_codecs(LinphoneCore *lc, MSList *codecs);
 /* returns a MSList of PayloadType */
-const MSList *linphone_core_get_video_codecs(LinphoneCore *lc);
+const MSList *linphone_core_get_video_codecs(const LinphoneCore *lc);
 
 int linphone_core_set_video_codecs(LinphoneCore *lc, MSList *codecs);
 
@@ -473,7 +484,7 @@ void linphone_core_add_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *confi
 
 void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *config);
 
-MSList *linphone_core_get_proxy_config_list(LinphoneCore *lc);
+const MSList *linphone_core_get_proxy_config_list(const LinphoneCore *lc);
 
 void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *config);
 
@@ -489,10 +500,12 @@ void linphone_core_clear_all_auth_info(LinphoneCore *lc);
 
 int linphone_core_get_audio_jittcomp(LinphoneCore *lc);
 
-int linphone_core_get_audio_port(LinphoneCore *lc);
-
 void linphone_core_set_audio_jittcomp(LinphoneCore *lc, int value);
 
+int linphone_core_get_audio_port(const LinphoneCore *lc);
+
+int linphone_core_get_video_port(const LinphoneCore *lc);
+
 void linphone_core_set_audio_port(LinphoneCore *lc, int port);
 
 void linphone_core_set_video_port(LinphoneCore *lc, int port);
@@ -513,20 +526,13 @@ void linphone_core_set_stun_server(LinphoneCore *lc, const char *server);
 
 const char * linphone_core_get_stun_server(const LinphoneCore *lc);
 
-void linphone_core_enable_stun(LinphoneCore *lc, bool_t val);
-
-bool_t linphone_core_stun_enabled(const LinphoneCore *lc);
-
-/* give a NULL addr to only set nat use */
 void linphone_core_set_nat_address(LinphoneCore *lc, const char *addr);
 
-const char *linphone_core_get_nat_address(LinphoneCore *lc);
+const char *linphone_core_get_nat_address(const LinphoneCore *lc);
 
-void linphone_core_use_nat_address(LinphoneCore *lc, bool_t val);
+void linphone_core_set_firewall_policy(LinphoneCore *lc, LinphoneFirewallPolicy pol);
 
-bool_t linphone_core_nat_address_used(const LinphoneCore *lc);
-
-const char *linphone_core_get_nat_address_if_used(LinphoneCore *lc);
+LinphoneFirewallPolicy linphone_core_get_firewall_policy(const LinphoneCore *lc);
 
 /* sound functions */
 /* returns a null terminated static array of string describing the sound devices */ 
