@@ -447,6 +447,7 @@ generating_register(osip_message_t **reg, char *from,
 	  contact = (char *) osip_malloc(50+strlen(a_from->url->username));
 	  if (eXosip.j_firewall_ip[0]!='\0')
 	    {
+		#if 0
 	      char *c_address = (*reg)->req_uri->host;
 
 		  struct addrinfo *addrinfo;
@@ -464,6 +465,7 @@ generating_register(osip_message_t **reg, char *from,
 
 	      if (eXosip_is_public_address(c_address))
 		{
+		#endif
 		  if (eXosip.localport==NULL)
 		    sprintf(contact, "<sip:%s@%s>", a_from->url->username,
 			    eXosip.j_firewall_ip);
@@ -471,6 +473,7 @@ generating_register(osip_message_t **reg, char *from,
 		    sprintf(contact, "<sip:%s@%s:%s>", a_from->url->username,
 			    eXosip.j_firewall_ip,
 			    eXosip.localport);
+		#if 0
 		}
 	      else
 		{
@@ -482,6 +485,7 @@ generating_register(osip_message_t **reg, char *from,
 			    locip,
 			    eXosip.localport);
 		}
+		#endif
 	    }
 	  else
 	    {
