@@ -108,6 +108,8 @@ typedef struct _VideoStream VideoStream;
 
 VideoStream *video_stream_start(RtpProfile *profile, int locport, const char *remip, int remport, int payload, int jitt_comp, const char *device);
 void video_stream_set_rtcp_information(VideoStream *st, const char *cname, const char *tool);
+/*function to call periodically to handle various events */
+void video_stream_iterate(VideoStream *stream);
 void video_stream_stop (VideoStream * stream);
 
 VideoStream * video_preview_start(const char *device);
