@@ -94,6 +94,11 @@ typedef struct _MSList MSList;
 
 #define ms_list_next(elem) ((elem)->next)
 
+
+#ifdef __cplusplus
+extern "C"{
+#endif
+
 MSList * ms_list_append(MSList *elem, void * data);
 MSList * ms_list_prepend(MSList *elem, void * data);
 MSList * ms_list_free(MSList *elem);
@@ -105,9 +110,9 @@ void ms_list_for_each2(const MSList *list, void (*func)(void *, void *), void *u
 MSList *ms_list_remove_link(MSList *list, MSList *elem);
 MSList *ms_list_find(MSList *list, void *data);
 MSList *ms_list_find_custom(MSList *list, int (*compare_func)(const void *, const void*), void *user_data);
-void * ms_list_nth_data(MSList *list, int index);
-int ms_list_position(MSList *list, MSList *elem);
-int ms_list_index(MSList *list, void *data);
+void * ms_list_nth_data(const MSList *list, int index);
+int ms_list_position(const MSList *list, MSList *elem);
+int ms_list_index(const MSList *list, void *data);
 MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(const void *, const void*));
 
 
@@ -117,11 +122,9 @@ MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(cons
 #define MAX(a,b)	((a)>(b) ? (a) : (b))
 #endif
 
-#ifdef __cplusplus
-extern "C"{
-#endif
 
 void ms_init(void);
+int ms_load_plugins(const char *directory);
 void ms_exit(void);
 
 #ifdef __cplusplus
