@@ -29,6 +29,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define MS_VIDEO_SIZE_QCIF_H 144
 #define MS_VIDEO_SIZE_4CIF_W 704
 #define MS_VIDEO_SIZE_4CIF_H 576
+
+#define MS_VIDEO_SIZE_QVGA_W 320
+#define MS_VIDEO_SIZE_QVGA_H 240
+#define MS_VIDEO_SIZE_VGA_W 640
+#define MS_VIDEO_SIZE_VGA_H 480
+
 #define MS_VIDEO_SIZE_MAX_W MS_VIDEO_SIZE_4CIF_W
 #define MS_VIDEO_SIZE_MAX_H MS_VIDEO_SIZE_4CIF_H
 
@@ -38,6 +44,10 @@ typedef struct MSVideoSize{
 
 #define MS_VIDEO_SIZE_CIF (MSVideoSize){MS_VIDEO_SIZE_CIF_W,MS_VIDEO_SIZE_CIF_H}
 #define MS_VIDEO_SIZE_QCIF (MSVideoSize){MS_VIDEO_SIZE_QCIF_W,MS_VIDEO_SIZE_QCIF_H}
+#define MS_VIDEO_SIZE_4CIF (MSVideoSize){MS_VIDEO_SIZE_4CIF_W,MS_VIDEO_SIZE_4CIF_H}
+
+#define MS_VIDEO_SIZE_QVGA (MSVideoSize){MS_VIDEO_SIZE_QVGA_W,MS_VIDEO_SIZE_QVGA_H}
+#define MS_VIDEO_SIZE_VGA (MSVideoSize){MS_VIDEO_SIZE_VGA_W,MS_VIDEO_SIZE_VGA_H}
 
 typedef enum{
 	MS_YUV420P,
