@@ -183,12 +183,14 @@ static int alsa_read(snd_pcm_t *handle,unsigned char *buf,int nsamples)
 		if (err==-EPIPE){
 			snd_pcm_prepare(handle);
 			err=snd_pcm_readi(handle,buf,nsamples);
-			if (err<0) ms_warning("alsa_card_read: snd_pcm_readi() failed:%s.",snd_strerror(err));
+			if (err<0) ms_warning("alsa_read: snd_pcm_readi() failed:%s.",snd_strerror(err));
 		}else if (err!=-EWOULDBLOCK){
-			ms_warning("alsa_card_read: snd_pcm_readi() failed:%s.",snd_strerror(err));
+			ms_warning("alsa_read: snd_pcm_readi() failed:%s.",snd_strerror(err));
+		}else if (err==0){
+			ms_warning("alsa_read: snd_pcm_readi() returned 0");
 		}
 	}
-	return nsamples;
+	return err;
 }
 
 
@@ -534,20 +536,23 @@ static bool_t alsa_can_read(snd_pcm_t *dev, int frames){
 void alsa_read_process(MSFilter *obj){
 	AlsaReadData *ad=(AlsaReadData*)obj->data;
 	int samples=(128*ad->rate)/8000;
-	int size=samples*2;
+	int err;
 	mblk_t *om=NULL;
 	if (ad->handle==NULL && ad->pcmdev!=NULL){
 		ad->handle=alsa_open_r(ad->pcmdev,16,ad->nchannels==2,ad->rate);
 	}
 	if (ad->handle==NULL) return;
 	while (alsa_can_read(ad->handle,samples)){
+		int size=samples*2;
 		om=allocb(size,0);
-		if (alsa_read(ad->handle,om->b_wptr,samples)!=samples){
+		if ((err=alsa_read(ad->handle,om->b_wptr,samples))<=0) {
 			ms_warning("Fail to read samples");
 			freemsg(om);
 			return;
 		}
+		size=err*2;
 		om->b_wptr+=size;
+		/*ms_message("alsa_read_process: Outputing %i bytes",size);*/
 		ms_queue_put(obj->outputs[0],om);
 	}
 }
@@ -638,7 +643,10 @@ void alsa_write_process(MSFilter *obj){
 	if (ad->handle==NULL && ad->pcmdev!=NULL){
 		ad->handle=alsa_open_w(ad->pcmdev,16,ad->nchannels==2,ad->rate);
 	}
-	if (ad->handle==NULL) return;
+	if (ad->handle==NULL) {
+		ms_queue_flush(obj->inputs[0]);
+		return;
+	}
 	while ((im=ms_queue_get(obj->inputs[0]))!=NULL){
 		while((size=im->b_wptr-im->b_rptr)>0){
 			samples=size/(2*ad->nchannels);
