@@ -124,11 +124,48 @@ RtpSession * create_duplex_rtpsession(RtpProfile *profile, int locport,const cha
 	rtp_session_set_payload_type(rtpr,payload);
 	rtp_session_set_jitter_compensation(rtpr,jitt_comp);
 	rtp_session_enable_adaptive_jitter_compensation(rtpr,TRUE);
+	rtp_session_set_symmetric_rtp(rtpr,TRUE);
 	/*rtp_session_signal_connect(rtpr,"timestamp_jump",(RtpCallback)on_timestamp_jump,NULL);*/
 	return rtpr;
 }
 
+/*this function must be called from the MSTicker thread:
+it replaces one filter by another one.
+This is a dirty hack that works anyway.
+It would be interesting to have something that does the job
+simplier within the MSTicker api
+*/
+void audio_stream_change_decoder(AudioStream *stream, int payload){
+	RtpSession *session=stream->session;
+	RtpProfile *prof=rtp_session_get_profile(session);
+	PayloadType *pt=rtp_profile_get_payload(prof,payload);
+	if (pt!=NULL){
+		MSFilter *dec=ms_filter_create_decoder(pt->mime_type);
+		if (dec!=NULL){
+			ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
+			ms_filter_unlink(stream->decoder,0,stream->dtmfgen,0);
+			ms_filter_postprocess(stream->decoder);
+			ms_filter_destroy(stream->decoder);
+			stream->decoder=dec;
+			if (pt->recv_fmtp!=NULL)
+				ms_filter_call_method(stream->decoder,MS_FILTER_SET_FMTP,(void*)pt->recv_fmtp);
+			ms_filter_link (stream->rtprecv, 0, stream->decoder, 0);
+			ms_filter_link (stream->decoder,0 , stream->dtmfgen, 0);
+			ms_filter_preprocess(stream->decoder,stream->ticker);
+			
+		}else{
+			ms_warning("No decoder found for %s",pt->mime_type);
+		}
+	}else{
+		ms_warning("No payload defined with number %i",payload);
+	}
+}
 
+static void payload_type_changed(RtpSession *session, unsigned long data){
+	AudioStream *stream=(AudioStream*)data;
+	int pt=rtp_session_get_recv_payload_type(stream->session);
+	audio_stream_change_decoder(stream,pt);
+}
 
 
 AudioStream * audio_stream_start_full(RtpProfile *profile, int locport, const char *remip,int remport, int payload,int jitt_comp, const char *infile, const char *outfile, MSSndCard *playcard, MSSndCard *captcard, bool_t use_ec)
@@ -147,6 +184,7 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport, const ch
 	
 	stream->dtmfgen=ms_filter_new(MS_DTMF_GEN_ID);
 	rtp_session_signal_connect(rtps,"telephone-event",(RtpCallback)on_dtmf_received,(unsigned long)stream->dtmfgen);
+	rtp_session_signal_connect(rtps,"payload_type_changed",(RtpCallback)payload_type_changed,(unsigned long)stream);
 	
 	/* creates the local part */
 	if (captcard!=NULL) stream->soundread=ms_snd_card_create_reader(captcard);
@@ -175,7 +213,10 @@ AudioStream * audio_stream_start_full(RtpProfile *profile, int locport, const ch
 		return NULL;
 	}
 	
-	if (use_ec) stream->ec=ms_filter_new(MS_SPEEX_EC_ID);	
+	if (use_ec) {
+		stream->ec=ms_filter_new(MS_SPEEX_EC_ID);
+		ms_filter_call_method(stream->ec,MS_FILTER_SET_SAMPLE_RATE,&pt->clock_rate);
+	}	
 
 	/* give the sound filters some properties */
 	ms_filter_call_method(stream->soundread,MS_FILTER_SET_SAMPLE_RATE,&pt->clock_rate);
