@@ -117,7 +117,11 @@ static int sender_unmute_mic(MSFilter * f, void *arg)
 static uint32_t get_cur_timestamp(MSFilter * f, uint32_t packet_ts)
 {
 	SenderData *d = (SenderData *) f->data;
+#if !defined(_WIN32_WCE)
 	uint32_t curts = (f->ticker->time * d->rate) / 1000LL;
+#else
+	uint32_t curts = (f->ticker->time * d->rate) / ((uint64_t)1000);
+#endif
 	int diff;
 	int delta = d->rate / 50;	/*20 ms at 8000Hz */
 	uint32_t netts;
@@ -304,7 +308,11 @@ static void receiver_process(MSFilter * f)
 
 	if (d->session == NULL)
 		return;
+#if !defined(_WIN32_WCE)
 	timestamp = (f->ticker->time * d->rate) / 1000LL;
+#else
+	timestamp = (f->ticker->time * d->rate) / ((uint64_t)1000);
+#endif
 	while ((m = rtp_session_recvm_with_ts(d->session, timestamp)) != NULL) {
 		mblk_t *payload = m->b_cont;
 
