@@ -237,8 +237,11 @@ static void run_graphs(MSTicker *s, MSList *execution_list, bool_t force_schedul
 
 #ifdef WIN32
 
+#if !defined(_WIN32_WCE)
 #include <sys/types.h>
 #include <sys/timeb.h>
+#endif
+
 /**
  * timespec structure
  * @struct timespec
@@ -251,8 +254,12 @@ static void run_graphs(MSTicker *s, MSList *execution_list, bool_t force_schedul
 #endif
 
 static uint64_t get_cur_time(){
+#if defined(_WIN32_WCE)
+	DWORD timemillis = GetTickCount();
+	return timemillis;
+#else
 	struct timespec ts;
-#ifdef WIN32
+#if defined(WIN32)
     struct _timeb time_val;
 
     _ftime (&time_val);
@@ -270,6 +277,7 @@ static uint64_t get_cur_time(){
 	}
 #endif
 	return (ts.tv_sec*1000LL) + (ts.tv_nsec/1000000LL);
+#endif
 }
 
 static void sleepMs(int ms){
