@@ -17,7 +17,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#if defined(_WIN32_WCE)
+#define DISABLE_SPEEX
+#endif
+
+#ifndef DISABLE_SPEEX
 #include <speex/speex_preprocess.h>
+#endif
 
 #include "mediastreamer2/mssndcard.h"
 #include "mediastreamer2/msfilter.h"
@@ -60,7 +66,9 @@ typedef struct WinSndData{
 	bool_t write_started;
 	bool_t stereo;
 
+#ifndef DISABLE_SPEEX
 	SpeexPreprocessState *pst;
+#endif
 } WinSndData;
 
 static void CALLBACK
@@ -140,13 +148,14 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
     	ms_mutex_lock(&device->mutex);
 		if (device->read_started)
         {
-			int vad;
             mblk_t *rm=NULL;
             if (rm==NULL) rm=allocb(wHdr->dwBufferLength,0);
 			memcpy(rm->b_wptr,wHdr->lpData, wHdr->dwBufferLength);
 
+#ifndef DISABLE_SPEEX
 			if (device->pst!=NULL)
 			{
+				int vad;
 				//memset(rm->b_wptr,0, wHdr->dwBufferLength);
 
 				vad = speex_preprocess(device->pst, (short*)rm->b_wptr, NULL);
@@ -156,6 +165,7 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
 #endif
 			}
 
+#endif
 			rm->b_wptr+=wHdr->dwBufferLength;
 		    
 			putq(&device->rq,rm);
@@ -285,6 +295,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
         }
     }
 
+#ifndef DISABLE_SPEEX
 #if 0
 	device->pst = speex_preprocess_state_init((device->rate/8000 * 320)/2, device->rate);
 	if (device->pst!=NULL) {
@@ -304,6 +315,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
 		f=.3;
 		speex_preprocess_ctl(device->pst, SPEEX_PREPROCESS_SET_DEREVERB_LEVEL, &f);
 	}
+#endif
 #endif
 
 	mr = waveInStart (device->waveindev);
@@ -406,7 +418,9 @@ static void winsnd_init(MSSndCard *card){
 	d->bufferizer=ms_bufferizer_new();
 	ms_mutex_init(&d->mutex,NULL);
 	card->data=d;
+#ifndef DISABLE_SPEEX
 	d->pst=0;
+#endif
 }
 
 static void winsnd_uninit(MSSndCard *card){
@@ -420,8 +434,10 @@ static void winsnd_uninit(MSSndCard *card){
 
 	ms_mutex_destroy(&d->mutex);
 
+#ifndef DISABLE_SPEEX
 	if (d->pst!=NULL)
 	    speex_preprocess_state_destroy(d->pst);
+#endif
 
 	ms_free(d);
 }
@@ -584,8 +600,13 @@ static void * winsnd_thread(void *p){
 
 
 					    if (err<0){
+#if !defined(_WIN32_WCE)
 						    ms_warning("Fail to write %i bytes from soundcard: %s",
-						    bsize,strerror(errno));
+							    bsize,strerror(errno));
+#else
+						    ms_warning("Fail to write %i bytes from soundcard: %i",
+							    bsize,WSAGetLastError());
+#endif
 					    }
 				    }
 					else
