@@ -22,7 +22,7 @@
 #define ORTP_PORT_H
 
 
-#ifndef _WIN32
+#if !defined(WIN32) && !defined(_WIN32_WCE)
 /********************************/
 /* definitions for UNIX flavour */
 /********************************/
@@ -203,7 +203,7 @@ char *ortp_strdup_printf(const char *fmt,...);
 #endif
 
 
-#if defined(WIN32) && !defined(ORTP_STATIC)
+#if (defined(WIN32) || defined(_WIN32_WCE)) && !defined(ORTP_STATIC)
 #ifdef ORTP_EXPORTS
    #define VAR_DECLSPEC    __declspec(dllexport)
 #else
