@@ -18,7 +18,7 @@
 */
 
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
 #include "ortp-config-win32.h"
 #else
 #include "ortp-config.h"
@@ -1421,12 +1421,7 @@ void *rtp_session_get_data(const RtpSession *session){
 void
 rtp_session_set_symmetric_rtp (RtpSession * session, int yesno)
 {
-	if (session==NULL) return;
-	session->symmetric_rtp = 0;
-	if (yesno)
-	{
-	  session->symmetric_rtp = 1;
-	}
+	session->symmetric_rtp = (yesno!=0);
 	return;
 }
 
