@@ -23,7 +23,7 @@
 #include "rtpsession_priv.h"
 
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
 #include "ortp-config-win32.h"
 #else
 #include "ortp-config.h" /*needed for HAVE_SYS_UIO_H */
@@ -151,7 +151,23 @@ static ortp_socket_t create_and_bind(const char *addr, int port, int *sock_famil
 		return -1;
 	}
 #endif
-	if (sock>=0) set_non_blocking_socket (sock);
+	if (sock>=0)
+	{
+#ifdef WIN32
+		/* increase RTP buffer on windows */
+		int bufsize = 32768;
+		err = setsockopt(sock, SOL_SOCKET, SO_SNDBUF, (void *)&bufsize, sizeof(bufsize)); 
+		if (err == -1) {
+			ortp_warning ("Fail to increase buffer size for socket (port %i): %s.", port, getSocketError());
+		}
+		bufsize = 32768;
+		err = setsockopt(sock, SOL_SOCKET, SO_RCVBUF, (void *)&bufsize, sizeof(bufsize)); 
+		if (err == -1) {
+			ortp_warning ("Fail to increase buffer size for socket (port %i): %s.", port, getSocketError());
+		}
+#endif
+		set_non_blocking_socket (sock);
+	}
 	return sock;
 }
 
