@@ -101,7 +101,7 @@ void * rtp_scheduler_schedule(void * psched)
 	RtpSession *current;
 
 	/* try to get the real time priority by getting root*/
-#ifndef _WIN32
+#if	!defined(_WIN32) && !defined(_WIN32_WCE)
 	
 	int err;
 
